#!/usr/bin/python
# Authors:
#     Endi S. Dewata <edewata@redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright (C) 2015 Red Hat, Inc.
# All rights reserved.
#

import getopt
import sys

import pki.server
import pki.server.upgrade

def print_help():
    print 'Usage: restore-subsystem-user.py [OPTIONS]'
    print
    print '  -s, --subsystem <directory>  Subsystem directory (default: /var/lib/pki-ca).'
    print
    print '  -v, --verbose                Run in verbose mode.'
    print '      --silent                 Run in silent mode.'
    print '      --help                   Show help message.'
    print

try:
    opts, _ = getopt.gnu_getopt(sys.argv, 's:v', [
        'subsystem=',
        'verbose', 'silent', 'help'])

except getopt.GetoptError as e:
    print 'ERROR: ' + str(e)
    print_help()
    sys.exit(1)

subsystem_dir = '/var/lib/pki-ca'
verbose = False
silent = False

for o, a in opts:
    if o in ('-v', '--verbose'):
        verbose = True

    elif o == '--silent':
        silent = True

    elif o == '--help':
        print_help()
        sys.exit()

    elif o in ('-s', '--subsystem'):
        subsystem_dir = a

    else:
        print 'ERROR: unknown option ' + o
        self.print_help()
        sys.exit(1)

subsystem = pki.server.PKISubsystem(subsystem_dir)

scriptlet = pki.server.upgrade.RestoreSubsystemUser()
scriptlet.subsystem = subsystem
scriptlet.verbose = verbose
scriptlet.silent = silent

scriptlet.execute()
